==> hyades.source_1.2.1_20040126_0954.zip: org/eclipse/hyades/execution/recorder/RecorderPlugin.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.execution.recorder;

import java.net.URL;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.core.runtime.IPluginDescriptor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.hyades.test.ui.TestUI;
import org.eclipse.hyades.test.ui.TestUIPlugin;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.plugin.AbstractUIPlugin;


/**
 * This plugin contains the Hyades infrastructure for trace recording.  It contains all the extendible object and interfaces
 * necessary to deploy a recorder on the RAC 
 * @author Ernest Jessee
 */
public class RecorderPlugin extends AbstractUIPlugin
{
	
	/**
	 * the default instance 
	 */
	private static RecorderPlugin plugin;
	
	/**
	 * the plugin's ID as shown in plugin.xml
	 */
	public static final String ID = "org.eclipse.hyades.execution.recorder"; //$NON-NLS-1$
	
	/**
	 * Stores a preference in the plugins preference store with the specified key and value 
	 * @param String key
	 * @param String value
	 */
	public static void storePreference(String key, String value)
	{
		getDefault().getPreferenceStore().setValue(key,value);
	}
	/**
	 *The plugins resourceBundle
	 */
	protected ResourceBundle resourceBundle;
	
	/**
	 * Returns the plugin's resource bundle,
	 */
	private ResourceBundle getResourceBundle()
	{
		return resourceBundle;
	}
	
	/**
	 * acquires a reference to a plugin preference specified by "key"
	 * @param String key
	 * @return String
	 */
	public static String getPreference(String key)
	{
		return getDefault().getPreferenceStore().getString(key);
	}	
	/**
	 * returns the plugins install URL
	 * @return URL
	 */
	public URL getInstallURL()
	{
		return getDescriptor().getInstallURL();
	}
	
	/**
	 * returns a resource String from this plugin's bundle
	 * @param String key
	 * @return String
	 */
	public static String getResourceString(String key)	
	{
		return RecorderPlugin.getDefault().getResourceBundle().getString(key);
	}
	
	
	/**
	 * The constructor.
	 */
	public RecorderPlugin(IPluginDescriptor descriptor) 
	{
		super(descriptor);
		plugin = this;
		try 
		{
			this.resourceBundle= ResourceBundle.getBundle("org.eclipse.hyades.execution.recorder.RecorderPlugin"); //$NON-NLS-1$
		} 
		catch (MissingResourceException x) 
		{
			resourceBundle = null;
		}
				
	}

	/**
	 * Returns the default instance.
	 */
	public static RecorderPlugin getDefault() 
	{
		return plugin;
	}
	
	
	/**
	 * return the port number specified for the Remote Agent Controller (RAC) as used by Hyades Test.  
	 * The value returned by this method is specified using Window->Preferences->Test
	 * @return String
	 */
	public String getRAServerPort()
	{
		return TestUIPlugin.getInstance().getPreferenceStore().getString(TestUI.LOCALHOST_PORT);
	}
	
	/**
	 * returns the host specified for the RAC as used by Hyades Test
	 * The value returend by this method is specified using Window->Preferences->Test
	 * @return String
	 */
	public String getRAServerHost()
	{
		return TestUIPlugin.getInstance().getPreferenceStore().getString(TestUI.DEFAULT_HOST_NAME);
	}
	
	/**
	 * This method causes a dialog box to be displayed warning the user of an exception.
	 * @param Exception e1 - the exception thrown 
	 * @param consequenceDescription - a description of the consequence (i.e. Recording session aborted)
	 * @param cause - a description of the cause. (i.e. Another recorder is active or Agent Controller not available on host/port)
	 * @param dlgTitle - the Title to be displayed on the error dialog
	 */
	public static void reportExceptionToUser(final Exception e1,
										     final String consequenceDescription,
										     final String cause,
										     final String dlgTitle)
	{
		Display.getDefault().asyncExec
		(
			new Runnable()
			{
				public void run()
				{
					Status errorStatus = new Status(IStatus.ERROR,RecorderPlugin.ID,IStatus.ERROR,cause,e1);
					new ErrorDialog(Display.getDefault().getActiveShell(),dlgTitle,consequenceDescription,errorStatus,IStatus.ERROR).open();
				
	
				}
	
			}
		);
	}

}

==> hyades.source_3.0.1.1_20041013_1609.zip: org/eclipse/hyades/execution/recorder/RecorderPlugin.java <==
/**********************************************************************
 * Copyright (c) 2003, 2004 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * 
 * Contributors: 
 * IBM Corporation - initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.execution.recorder;

import java.net.URL;
import java.util.ResourceBundle;

import org.eclipse.core.runtime.IPluginDescriptor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.hyades.test.ui.TestUI;
import org.eclipse.hyades.test.ui.TestUIPlugin;
import org.eclipse.hyades.ui.internal.util.StringUtil;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.plugin.AbstractUIPlugin;


/**
 * This plugin contains the Hyades infrastructure for trace recording.  It contains all the extendible object and interfaces
 * necessary to deploy a recorder on the RAC 
 * @author Ernest Jessee
 */
public class RecorderPlugin extends AbstractUIPlugin
{
	
	/**
	 * the default instance 
	 */
	private static RecorderPlugin plugin;
	
	/**
	 * the plugin's ID as shown in plugin.xml
	 */
	public static final String ID = "org.eclipse.hyades.execution.recorder"; //$NON-NLS-1$
	
	/**
	 * Stores a preference in the plugins preference store with the specified key and value 
	 * @param String key
	 * @param String value
	 */
	public static void storePreference(String key, String value)
	{
		getDefault().getPreferenceStore().setValue(key,value);
	}
	
	/**
	 * Returns the plugin's resource bundle,
	 */
	private ResourceBundle getResourceBundle()
	{
		return getDescriptor().getResourceBundle();
	}
	
	/**
	 * acquires a reference to a plugin preference specified by "key"
	 * @param String key
	 * @return String
	 */
	public static String getPreference(String key)
	{
		return getDefault().getPreferenceStore().getString(key);
	}	
	/**
	 * returns the plugins install URL
	 * @return URL
	 */
	public URL getInstallURL()
	{
		return getDescriptor().getInstallURL();
	}
	
	/**
	 * returns a resource String from this plugin's bundle
	 * @param String key
	 * @return String
	 */
	public static String getResourceString(String key)	
	{
		return RecorderPlugin.getDefault().getResourceBundle().getString(key);
	}
	
	
	/**
	 * The constructor.
	 */
	public RecorderPlugin(IPluginDescriptor descriptor) 
	{
		super(descriptor);
		plugin = this;
				
	}

	/**
	 * Returns the default instance.
	 */
	public static RecorderPlugin getDefault() 
	{
		return plugin;
	}
	
	
	/**
	 * return the port number specified for the Remote Agent Controller (RAC) as used by Hyades Test.  
	 * The value returned by this method is specified using Window->Preferences->Test
	 * @return String
	 */
	public String getRAServerPort()
	{
		return TestUIPlugin.getInstance().getPreferenceStore().getString(TestUI.LOCALHOST_PORT);
	}
	
	/**
	 * returns the host specified for the RAC as used by Hyades Test
	 * The value returend by this method is specified using Window->Preferences->Test
	 * @return String
	 */
	public String getRAServerHost()
	{
		return TestUIPlugin.getInstance().getPreferenceStore().getString(TestUI.DEFAULT_HOST_NAME);
	}
	
	/**
	 * This method causes a dialog box to be displayed warning the user of an exception.
	 * @param Exception e1 - the exception thrown 
	 * @param consequenceDescription - a description of the consequence (i.e. Recording session aborted)
	 * @param cause - a description of the cause. (i.e. Another recorder is active or Agent Controller not available on host/port)
	 * @param dlgTitle - the Title to be displayed on the error dialog
	 */
	public static void reportExceptionToUser(final Exception e1,
										     final String consequenceDescription,
										     final String cause,
										     final String dlgTitle)
	{
		Display.getDefault().asyncExec
		(
			new Runnable()
			{
				public void run()
				{
					Status errorStatus = new Status(IStatus.ERROR,RecorderPlugin.ID,IStatus.ERROR,cause,e1);
					new ErrorDialog(Display.getDefault().getActiveShell(),dlgTitle,consequenceDescription,errorStatus,IStatus.ERROR).open();
				
	
				}
	
			}
		);
	}

	public String getString(String key, String[]args)	
	{
		
		String ret = RecorderPlugin.getResourceString(key);
		for (int i = args.length; i > 0; i--)
			ret = StringUtil.replace(ret, ("%"+i), args[i-1]);
		
		return ret;
	}	

}
